﻿using RimWorld;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using UnityEngine;
using Verse;

namespace MyMod
{
    public class MyModSettings : ModSettings
    {
        private string weatherDefString;
        private WeatherDef weatherDef;
        public WeatherDef WeatherDef
        {
            get
            {
                if (weatherDef == null)
                {
                    if (!weatherDefString.NullOrEmpty())
                    {
                        weatherDef = DefDatabase<WeatherDef>.GetNamed(weatherDefString);
                    }
                    else
                    {
                        weatherDef = WeatherDefOf.Clear;
                    }
                }

                return weatherDef;
            }
        }

        public IntRange raidPowerRange = new IntRange(100, 500);

        private Vector2 scrollPosition = Vector2.zero;
        private float viewRectHeight;

        public int lightningCount = 1;
        private string lightningCountBuff;

        public int needFoodSatisfyingSpeed = 500;
        private string needFoodSatisfyingSpeedBuff;

        public void DoSettingsWindowContents(Rect inRect)
        {
            Rect viewRect = new Rect(0, 0, inRect.width - 16f, viewRectHeight);
            Widgets.BeginScrollView(inRect, ref scrollPosition, viewRect);

            Listing_Standard listing_Standard = new Listing_Standard();
            listing_Standard.ColumnWidth = inRect.width;

            Rect listingRect = inRect.AtZero();
            listingRect.height = 99999f;

            listing_Standard.Begin(listingRect);
            if (listing_Standard.ButtonText("MyModSettings_SelectWeatherDef".Translate(WeatherDef.LabelCap)))
            {
                List<FloatMenuOption> weatherDefs = new List<FloatMenuOption>();
                foreach(WeatherDef weatherDef in DefDatabase<WeatherDef>.AllDefs)
                {
                    weatherDefs.Add(new FloatMenuOption(weatherDef.LabelCap, () =>
                    {
                        weatherDefString = weatherDef.defName;
                        this.weatherDef = null;
                    }));
                }

                Find.WindowStack.Add(new FloatMenu(weatherDefs));
            }
            listing_Standard.Label("MyModSettings_RaidPowerRange".Translate());
            listing_Standard.IntRange(ref raidPowerRange, 1, 10000);
            listing_Standard.TextFieldNumericLabeled("MyModSettings_LightningCount".Translate(), ref lightningCount, ref lightningCountBuff, 1, 1000);
            listing_Standard.TextFieldNumericLabeled("MyModSettings_NeedFoodSatisfyingSpeed".Translate(), ref needFoodSatisfyingSpeed, ref needFoodSatisfyingSpeedBuff, 50, 50000);
            listing_Standard.End();
            viewRectHeight = listing_Standard.CurHeight;

            Widgets.EndScrollView();
        }

        public override void ExposeData()
        {
            base.ExposeData();

            Scribe_Values.Look(ref weatherDefString, "weatherDefString");
            Scribe_Values.Look(ref raidPowerRange, "raidPowerRange", new IntRange(100, 500));
            Scribe_Values.Look(ref lightningCount, "lightningCount", 1);
            Scribe_Values.Look(ref needFoodSatisfyingSpeed, "needFoodSatisfyingSpeed", 500);
        }
    }
}
